@@ -1,3 +1,4 @@
+/* -*- js-indent-level: 8 -*- */
 /*
  * L.Map is the central class of the API - it is used to create a map.
  */
@@ -20,6 +21,8 @@ L.Map = L.Evented.extend({
 		urlPrefix: 'lool'
 	},
 
+	lastActiveTime: Date.now(),
+
 	initialize: function (id, options) { // (HTMLElement or String, Object)
 		options = L.setOptions(this, options);
 
@@ -67,6 +70,8 @@ L.Map = L.Evented.extend({
 		this._active = true;
 		this._fatal = false;
 		this._enabled = true;
+		this._debugAlwaysActive = false; // disables the dimming / document inactivity when true
+		this._serverRecycling = false;
 
 		vex.dialogID = -1;
 
@@ -93,11 +98,20 @@ L.Map = L.Evented.extend({
 		};
 		this.initComplete = false;
 
-		this.on('updatepermission', function() {
+		this.on('updatepermission', function(e) {
 			if (!this.initComplete) {
 				this._fireInitComplete('updatepermission');
 			}
-		});
+
+			if (e.perm === 'readonly') {
+				L.DomUtil.addClass(this._container.parentElement, 'readonly');
+				L.DomUtil.addClass(L.DomUtil.get('logo'), 'readonly');
+				L.DomUtil.addClass(L.DomUtil.get('toolbar-wrapper'), 'readonly');
+				L.DomUtil.addClass(L.DomUtil.get('main-menu'), 'readonly');
+				L.DomUtil.addClass(L.DomUtil.get('presentation-controls-wrapper'), 'readonly');
+				L.DomUtil.addClass(L.DomUtil.get('spreadsheet-row-column-frame'), 'readonly');
+			}
+		}, this);
 		this.on('doclayerinit', function() {
 			if (!this.initComplete) {
 				this._fireInitComplete('doclayerinit');
@@ -123,16 +137,33 @@ L.Map = L.Evented.extend({
 
 		// View color map
 		this._viewColors = {};
+
+		// This becomes true if document was ever modified by the user
+		this._everModified = false;
+
+		this.on('commandstatechanged', function(e) {
+			if (e.commandName === '.uno:ModifiedStatus')
+				this._everModified = this._everModified || (e.state === 'true');
+		}, this);
 	},
 
 	// public methods that modify map state
 
-	addView: function(viewid, userid, username, color) {
-		this._viewInfo[viewid] = {'userid': userid, 'username': username, 'color': color};
-		this.fire('postMessage', {msgId: 'View_Added', args: {ViewId: viewid, UserId: userid, UserName: username, Color: color}});
+	getViewId: function (username) {
+		for (var idx in this._viewInfo) {
+			if (this._viewInfo[idx].username === username) {
+				return this._viewInfo[idx].id;
+			}
+		}
+		return -1;
+	},
+
+	addView: function(viewInfo) {
+		this._viewInfo[viewInfo.id] = viewInfo;
+		this.fire('postMessage', {msgId: 'View_Added', args: {ViewId: viewInfo.id, UserId: viewInfo.userid, UserName: viewInfo.username, Color: L.LOUtil.rgbToHex(viewInfo.color), ReadOnly: viewInfo.readonly}});
 
 		// Fire last, otherwise not all events are handled correctly.
-		this.fire('addview', {viewId: viewid, username: username});
+		this.fire('addview', {viewId: viewInfo.id, username: viewInfo.username, readonly: this.isViewReadOnly(viewInfo.id)});
 	},
 
 	removeView: function(viewid) {
@@ -248,10 +279,11 @@ L.Map = L.Evented.extend({
 		return this.fire('moveend');
 	},
 
-	setMaxBounds: function (bounds) {
+	setMaxBounds: function (bounds, options) {
 		bounds = L.latLngBounds(bounds);
 
 		this.options.maxBounds = bounds;
+		options = options || {};
 
 		if (!bounds) {
 			return this.off('moveend', this._panInsideMaxBounds);
@@ -261,6 +293,10 @@ L.Map = L.Evented.extend({
 			this._panInsideMaxBounds();
 		}
 
+		if (options.panInside === false) {
+			return this.off('moveend', this._panInsideMaxBounds);
+		}
+
 		return this.on('moveend', this._panInsideMaxBounds);
 	},
 
@@ -283,7 +319,6 @@ L.Map = L.Evented.extend({
 
 		var oldSize = this.getSize();
 		this._sizeChanged = true;
-		this._initialCenter = null;
 
 		var newSize = this.getSize(),
 		    oldCenter = oldSize.divideBy(2).round(),
@@ -391,12 +426,12 @@ L.Map = L.Evented.extend({
 		return this._viewInfo[viewid].color;
 	},
 
+	isViewReadOnly: function(viewid) {
+		return this._viewInfo[viewid].readonly !== '0';
+	},
+
 	getCenter: function () { // (Boolean) -> LatLng
 		this._checkIfLoaded();
-
-		if (this._initialCenter && !this._moved()) {
-			return this._initialCenter;
-		}
 		return this.layerPointToLatLng(this._getCenterLayerPoint());
 	},
 
@@ -564,7 +599,9 @@ L.Map = L.Evented.extend({
 	},
 
 	focus: function () {
+		console.debug('focus:');
 		if (this._docLayer && document.activeElement !== this._docLayer._textArea) {
+			console.debug('focus: focussing');
 			this._docLayer._textArea.focus();
 		}
 	},
@@ -598,6 +635,8 @@ L.Map = L.Evented.extend({
 		this._textArea.setAttribute('type', 'text');
 		this._textArea.setAttribute('autocorrect', 'off');
 		this._textArea.setAttribute('autocapitalize', 'off');
+		this._textArea.setAttribute('autocomplete', 'off');
+		this._textArea.setAttribute('spellcheck', 'false');
 		this._resizeDetector = L.DomUtil.create('iframe', 'resize-detector', container);
 		this._fileDownloader = L.DomUtil.create('iframe', '', container);
 		L.DomUtil.setStyle(this._fileDownloader, 'display', 'none');
@@ -664,7 +703,6 @@ L.Map = L.Evented.extend({
 		}
 
 		this._zoom = zoom;
-		this._initialCenter = center;
 
 		if (!preserveMapOffset) {
 			L.DomUtil.setPosition(this._mapPane, new L.Point(0, 0));
@@ -740,38 +778,127 @@ L.Map = L.Evented.extend({
 	},
 
 	_activate: function () {
+		if (this._serverRecycling) {
+			return;
+		}
+
+		console.debug('_activate:');
 		clearTimeout(vex.timer);
 
 		if (!this._active) {
 			// Only activate when we are connected.
 			if (this._socket.connected()) {
+				console.debug('sending useractive');
 				this._socket.sendMessage('useractive');
 				this._active = true;
-				this._docLayer._onMessage('invalidatetiles: EMPTY', null);
+				if (this._doclayer) {
+					this._docLayer._onMessage('invalidatetiles: EMPTY', null);
+				}
+				if (vex.dialogID > 0) {
+					var id = vex.dialogID;
+					vex.dialogID = -1;
+					this._startInactiveTimer();
+					this.focus();
+					return vex.close(id);
+				}
 			} else {
-				this._active = true;
 				this._socket.initialize(this);
 			}
-
-			if (vex.dialogID > 0) {
-				var id = vex.dialogID;
-				vex.dialogID = -1;
-				return vex.close(id);
-			}
 		}
 
+		this._startInactiveTimer();
+		this.focus();
 		return false;
 	},
 
-	_deactivate: function () {
+	_dim: function() {
+		if (this.options.alwaysActive || this._debugAlwaysActive === true) {
+			return;
+		}
+
+		console.debug('_dim:');
+		if (!this._socket.connected()) {
+			return;
+		}
+
+		this._active = false;
 		clearTimeout(vex.timer);
 
-		if (!window.devtools.open && (!this._active || vex.dialogID > 0)) {
+		var options = $.extend({}, vex.defaultOptions, {
+			contentCSS: {'background':'rgba(0, 0, 0, 0)',
+				     'font-size': 'xx-large',
+				     'color': '#fff',
+				     'text-align': 'center'},
+			content: _('Inactive document - please click to resume editing')
+		});
+		options.id = vex.globalID;
+		vex.dialogID = options.id;
+		vex.globalID += 1;
+		options.$vex = $('<div>').addClass(vex.baseClassNames.vex).addClass(options.className).css(options.css).data({
+			vex: options
+		});
+		options.$vexOverlay = $('<div>').addClass(vex.baseClassNames.overlay).addClass(options.overlayClassName).css(options.overlayCSS).data({
+			vex: options
+		});
+
+		var map = this;
+		options.$vex.bind('click.vex', function(e) {
+			console.debug('_dim: click.vex function');
+			return map._activate();
+		});
+		options.$vex.append(options.$vexOverlay);
+
+		options.$vexContent = $('<div>').addClass(vex.baseClassNames.content).addClass(options.contentClassName).css(options.contentCSS).text(options.content).data({
+			vex: options
+		});
+		options.$vex.append(options.$vexContent);
+
+		$(options.appendLocation).append(options.$vex);
+		vex.setupBodyClassName(options.$vex);
+
+		this._doclayer && this._docLayer._onMessage('textselection:', null);
+		console.debug('_dim: sending userinactive');
+		map.fire('postMessage', {msgId: 'User_Idle'});
+		this._socket.sendMessage('userinactive');
+	},
+
+	_dimIfInactive: function () {
+		console.debug('_dimIfInactive: diff=' + (Date.now() - this.lastActiveTime));
+		if ((Date.now() - this.lastActiveTime) >= this.options.idleTimeoutSecs * 1000) {
+			this._dim();
+		} else {
+			this._startInactiveTimer();
+		}
+	},
+
+	_startInactiveTimer: function () {
+		if (this._serverRecycling) {
+			return;
+		}
+
+		console.debug('_startInactiveTimer:');
+		clearTimeout(vex.timer);
+		var map = this;
+		vex.timer = setTimeout(function() {
+			map._dimIfInactive();
+		}, 1 * 60 * 1000); // Check once a minute
+	},
+
+	_deactivate: function () {
+		if (this._serverRecycling) {
+			return;
+		}
+
+		console.debug('_deactivate:');
+		clearTimeout(vex.timer);
+
+		if (!this._active || vex.dialogID > 0) {
 			// A dialog is already dimming the screen and probably
 			// shows an error message. Leave it alone.
 			this._active = false;
 			this._docLayer && this._docLayer._onMessage('textselection:', null);
 			if (this._socket.connected()) {
+				console.debug('_deactivate: sending userinactive');
 				this._socket.sendMessage('userinactive');
 			}
 
@@ -780,47 +907,8 @@ L.Map = L.Evented.extend({
 
 		var map = this;
 		vex.timer = setTimeout(function() {
-			if (window.devtools.open || !map._socket.connected()) {
-				return;
-			}
-
-			map._active = false;
-			clearTimeout(vex.timer);
-
-			var options = $.extend({}, vex.defaultOptions, {
-				contentCSS: {'background':'rgba(0, 0, 0, 0)',
-				             'font-size': 'xx-large',
-				             'color': '#fff',
-				             'text-align': 'center'},
-				content: _('Inactive document - please click to resume editing')
-			});
-			options.id = vex.globalID;
-			vex.dialogID = options.id;
-			vex.globalID += 1;
-			options.$vex = $('<div>').addClass(vex.baseClassNames.vex).addClass(options.className).css(options.css).data({
-				vex: options
-			});
-			options.$vexOverlay = $('<div>').addClass(vex.baseClassNames.overlay).addClass(options.overlayClassName).css(options.overlayCSS).data({
-				vex: options
-			});
-
-			options.$vex.bind('click.vex', function(e) {
-				return map._activate();
-			});
-			options.$vex.append(options.$vexOverlay);
-
-			options.$vexContent = $('<div>').addClass(vex.baseClassNames.content).addClass(options.contentClassName).css(options.contentCSS).text(options.content).data({
-				vex: options
-			});
-			options.$vex.append(options.$vexContent);
-
-			$(options.appendLocation).append(options.$vex);
-			vex.setupBodyClassName(options.$vex);
-
-			map._doclayer && map._docLayer._onMessage('textselection:', null);
-			map._socket.sendMessage('userinactive');
-
-		}, 30 * 1000); // Dim in 30 seconds.
+			map._dim();
+		}, map.options.outOfFocusTimeoutSecs * 1000);
 	},
 
 	_onLostFocus: function () {
@@ -844,6 +932,7 @@ L.Map = L.Evented.extend({
 	},
 
 	_onGotFocus: function () {
+		console.debug('_onGotFocus:');
 		if (!this._loaded) { return; }
 
 		var doclayer = this._docLayer;
@@ -866,7 +955,7 @@ L.Map = L.Evented.extend({
 
 	_onUpdateProgress: function (e) {
 		if (e.statusType === 'start') {
-			if (this._socket.readyState === 1) {
+			if (this._socket.socket.readyState === 1) {
 				// auto-save
 				this.showBusy(_('Saving...'), true);
 			}
@@ -896,6 +985,8 @@ L.Map = L.Evented.extend({
 	_handleDOMEvent: function (e) {
 		if (!this._loaded || !this._enabled || L.DomEvent._skipped(e)) { return; }
 
+		this.lastActiveTime = Date.now();
+
 		// find the layer the event is propagating from
 		var target = this._targets[L.stamp(e.target || e.srcElement)],
 			//type = e.type === 'keypress' && e.keyCode === 13 ? 'click' : e.type;
@@ -904,9 +995,16 @@ L.Map = L.Evented.extend({
 		// For touch devices, to pop-up the keyboard, it is required to call
 		// .focus() method on hidden input within actual 'click' event here
 		// Calling from some other place with no real 'click' event doesn't work
-		if (type === 'click' && this._permission === 'edit') {
-			this._textArea.blur();
-			this._textArea.focus();
+		if (type === 'click') {
+			if (this._permission === 'edit') {
+				this._textArea.blur();
+				this._textArea.focus();
+			}
+
+			// unselect if anything is selected already
+			if (this._docLayer && this._docLayer._annotations && this._docLayer._annotations.unselect) {
+				this._docLayer._annotations.unselect();
+			}
 		}
 
 		// we need to keep track if we have entered/left the map
